import { Construct } from 'constructs';
import { EventType, IBucket } from 'aws-cdk-lib/aws-s3';
import { BackendOutputStorageStrategy, ConstructFactory, FunctionResources, ResourceProvider } from '@aws-amplify/plugin-types';
import { StorageOutput } from '@aws-amplify/backend-output-schemas';
import { IFunction } from 'aws-cdk-lib/aws-lambda';
export type AmplifyStorageTriggerEvent = 'onDelete' | 'onUpload';
export type AmplifyStorageProps = {
    name: string;
    versioned?: boolean;
    outputStorageStrategy?: BackendOutputStorageStrategy<StorageOutput>;
    triggers?: Partial<Record<AmplifyStorageTriggerEvent, ConstructFactory<ResourceProvider<FunctionResources>>>>;
};
export type StorageResources = {
    bucket: IBucket;
};
/**
 * Amplify Storage CDK Construct
 *
 * Currently just a thin wrapper around an S3 bucket
 */
export declare class AmplifyStorage extends Construct implements ResourceProvider<StorageResources> {
    readonly resources: StorageResources;
    /**
     * Create a new AmplifyStorage instance
     */
    constructor(scope: Construct, id: string, props: AmplifyStorageProps);
    /**
     * Attach a Lambda function trigger handler to the S3 events
     * @param events - list of S3 events that will trigger the handler
     * @param handler - The function that will handle the event
     */
    addTrigger: (events: EventType[], handler: IFunction) => void;
    /**
     * Store storage outputs using provided strategy
     */
    private storeOutput;
}
//# sourceMappingURL=construct.d.ts.map